/*******************************************************************************
***  This file is part of Dux Rei Nummariae.                                 ***
***                                                                          ***
***  Copyright (C) 2017, 2018, 2019, 2020, 2021, 2022, 2023, 2024            ***
***  John Schneiderman <Licencing _AT_ Schneiderman _DOT_ me>                ***
***                                                                          ***
***  This program is free software: you can redistribute it and/or modify it ***
***  under the terms of the GNU Affero General Public License as published   ***
***  by the Free Software Foundation, either version 3 of the License, or    ***
***  (at your option) any later version.                                     ***
***                                                                          ***
***  This program is distributed in the hope that it will be useful, but     ***
***  WITHOUT ANY WARRANTY; without even the implied warranty of              ***
***  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    ***
***  See the GNU Affero General Public License for more details.             ***
***                                                                          ***
***  You should have received a copy of the GNU Affero General Public License***
***  along with this program. If not, see <http://www.gnu.org/licenses/>.    ***
*******************************************************************************/
#ifndef DRN_ACCOUNTING_ACCOUNTINGERRORS_H_
#define DRN_ACCOUNTING_ACCOUNTINGERRORS_H_

#include <accounting_export.h>
#include <foundation/Error.h>


class QString;

namespace drn::accounting
{

class AccountCode;
class AccountNumber;
class Transaction;
class TransactionNumber;

/**
 * @brief This represents an issue with an Account operation.
 */
struct DRN_ACCOUNTING_EXPORT AccountError final : foundation::Error
{
	AccountError(
		const AccountCode& ac,
		const ::QString& message,
		const std::exception& root = {}
	);
	AccountError(const AccountCode&, const char*, const std::exception& = {}) = delete;
};
/**
 * @brief This represents an issue with a Transaction operation.
 */
struct DRN_ACCOUNTING_EXPORT TransactionError final : foundation::Error
{
	TransactionError(
		const TransactionNumber& tn,
		const ::QString& message,
		const std::exception& root = {}
	);
	TransactionError(
		const std::optional<TransactionNumber>& tn,
		const Transaction& t,
		const ::QString& message,
		const std::exception& root = {}
	);
	TransactionError(
		const std::optional<TransactionNumber>&,
		const Transaction&,
		const char*,
		const std::exception& = {}
	) = delete;
};

}

#endif
