/*******************************************************************************
***  This file is part of Dux Rei Nummariae.                                 ***
***                                                                          ***
***  Copyright (C) 2017, 2018, 2019, 2020, 2021, 2022, 2023, 2024            ***
***  John Schneiderman <Licencing _AT_ Schneiderman _DOT_ me>                ***
***                                                                          ***
***  This program is free software: you can redistribute it and/or modify it ***
***  under the terms of the GNU Affero General Public License as published   ***
***  by the Free Software Foundation, either version 3 of the License, or    ***
***  (at your option) any later version.                                     ***
***                                                                          ***
***  This program is distributed in the hope that it will be useful, but     ***
***  WITHOUT ANY WARRANTY; without even the implied warranty of              ***
***  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    ***
***  See the GNU Affero General Public License for more details.             ***
***                                                                          ***
***  You should have received a copy of the GNU Affero General Public License***
***  along with this program. If not, see <http://www.gnu.org/licenses/>.    ***
*******************************************************************************/
#ifndef DRN_ACCOUNTING_OPEN_STATES_H_
#define DRN_ACCOUNTING_OPEN_STATES_H_

#include <QtCore>

#include <accounting_export.h>
#include <foundation/EnumFlags.hpp>


class QDebug;

namespace drn::accounting
{

/**
 * @brief Represents the states in which an account or item can exist.
 */
enum class DRN_ACCOUNTING_EXPORT OpenStates : quint8
{
	/// Indicates that it is currently open or active.
	Opened = 0b01,
	///Indicates that it is currently closed or inactive.
	Closed = 0b10,
};

/**
 * @brief Full object Qt stream insertion operator.
 *
 * @param out The stream to place the data into.
 * @param data The data to place into the stream.
 *
 * @return The modified stream after insertion.
 */
DRN_ACCOUNTING_EXPORT ::QDebug operator<<(::QDebug out, const OpenStates& data);

}

REGISTER_ENUM_AS_FLAG(drn::accounting::OpenStates);

#endif
