/*******************************************************************************
***  This file is part of Dux Rei Nummariae.                                 ***
***                                                                          ***
***  Copyright (C) 2017, 2018, 2019, 2020, 2021, 2022, 2023, 2024            ***
***  John Schneiderman <Licencing _AT_ Schneiderman _DOT_ me>                ***
***                                                                          ***
***  This program is free software: you can redistribute it and/or modify it ***
***  under the terms of the GNU Affero General Public License as published   ***
***  by the Free Software Foundation, either version 3 of the License, or    ***
***  (at your option) any later version.                                     ***
***                                                                          ***
***  This program is distributed in the hope that it will be useful, but     ***
***  WITHOUT ANY WARRANTY; without even the implied warranty of              ***
***  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    ***
***  See the GNU Affero General Public License for more details.             ***
***                                                                          ***
***  You should have received a copy of the GNU Affero General Public License***
***  along with this program. If not, see <http://www.gnu.org/licenses/>.    ***
*******************************************************************************/
#ifndef DRN_BANKING_LAST_RECONCILED_BALANCE_H_
#define DRN_BANKING_LAST_RECONCILED_BALANCE_H_

#include <pecunia/Money.hpp>

#include <QDate>

#include <banking_export.h>


namespace drn::banking
{

/**
 * @brief Represents a reconciled balance for a bank account.
 */
struct DRN_BANKING_EXPORT ReconciledBalance
{
	/// Represents the confirmed reconciled balance.
	pecunia::Money balance_{};
	/// Represents the date the reconciliation was performed on.
	::QDate occurredOn_{};
};

/**
 * @brief Full object Qt stream insertion operator.
 *
 * @param out The stream to place the data into.
 * @param lr The data to place into the stream.
 *
 * @return The modified stream after insertion.
 */
DRN_BANKING_EXPORT ::QDebug operator<<(::QDebug out, const ReconciledBalance& lr);

}

#endif
