/*******************************************************************************
***  This file is part of Dux Rei Nummariae.                                 ***
***                                                                          ***
***  Copyright (C) 2017, 2018, 2019, 2020, 2021, 2022, 2023, 2024            ***
***  John Schneiderman <Licencing _AT_ Schneiderman _DOT_ me>                ***
***                                                                          ***
***  This program is free software: you can redistribute it and/or modify it ***
***  under the terms of the GNU Affero General Public License as published   ***
***  by the Free Software Foundation, either version 3 of the License, or    ***
***  (at your option) any later version.                                     ***
***                                                                          ***
***  This program is distributed in the hope that it will be useful, but     ***
***  WITHOUT ANY WARRANTY; without even the implied warranty of              ***
***  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    ***
***  See the GNU Affero General Public License for more details.             ***
***                                                                          ***
***  You should have received a copy of the GNU Affero General Public License***
***  along with this program. If not, see <http://www.gnu.org/licenses/>.    ***
*******************************************************************************/
#ifndef DRN_BUDGETING_DEBT_MAP_H_
#define DRN_BUDGETING_DEBT_MAP_H_

#include <budgeting_export.h>

#include "BudgetedMoneyMap.hpp"
#include "Debt.h"


namespace drn::budgeting
{

/**
 * @brief Maps all the Debts to their source.
 */
struct DRN_BUDGETING_EXPORT DebtMap final : BudgetedMoneyMap<Debt>
{
	using BudgetedMoneyMap<Debt>::BudgetedMoneyMap;

	/**
	 * @brief Changes the debt to the newly supplied one indexed by the source of the
	 * budgeted money.
	 *
	 * @exception BudgetItemError When the supplied source source does not exist.
	 * @exception BudgetItemError When the amount borrowed is changed.
	 *
	 * @param updated The new budgeted money to update the indexed entry to.
	 */
	void update(Debt updated);
};

}

#endif
