/*******************************************************************************
***  This file is part of Dux Rei Nummariae.                                 ***
***                                                                          ***
***  Copyright (C) 2017, 2018, 2019, 2020, 2021, 2022, 2023, 2024            ***
***  John Schneiderman <Licencing _AT_ Schneiderman _DOT_ me>                ***
***                                                                          ***
***  This program is free software: you can redistribute it and/or modify it ***
***  under the terms of the GNU Affero General Public License as published   ***
***  by the Free Software Foundation, either version 3 of the License, or    ***
***  (at your option) any later version.                                     ***
***                                                                          ***
***  This program is distributed in the hope that it will be useful, but     ***
***  WITHOUT ANY WARRANTY; without even the implied warranty of              ***
***  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    ***
***  See the GNU Affero General Public License for more details.             ***
***                                                                          ***
***  You should have received a copy of the GNU Affero General Public License***
***  along with this program. If not, see <http://www.gnu.org/licenses/>.    ***
*******************************************************************************/
#ifndef DRN_BUDGETING_WAGE_H_
#define DRN_BUDGETING_WAGE_H_

#include <iosfwd>

#include <budgeting_export.h>

#include "BudgetedMoney.h"


class QDebug;

namespace drn::budgeting
{

/**
 * @brief Represents a recurring stream of monetary income, including its periodicity and amount.
 *
 * This class is intended to model a scheduled income, such as a net wage or salary, that occurs
 * over regular intervals. It allows handling of monetary value and tracking its frequency
 * for financial calculations or planning.
 */
struct DRN_BUDGETING_EXPORT Wage final : BudgetedMoney
{
	using BudgetedMoney::BudgetedMoney;
};

/**
 * @brief Full object standard stream insertion operator.
 *
 * @param out The stream to place the data into.
 * @param data The data to place into the stream.
 *
 * @return The modified stream after insertion.
 */
DRN_BUDGETING_EXPORT std::ostream& operator<<(std::ostream& out, const Wage& data);
/**
 * @brief Full object Qt stream insertion operator.
 *
 * @param out The stream to place the data into.
 * @param data The data to place into the stream.
 *
 * @return The modified stream after insertion.
 */
DRN_BUDGETING_EXPORT ::QDebug operator<<(::QDebug out, const Wage& data);

}

#endif
