/*******************************************************************************
***  This file is part of Dux Rei Nummariae.                                 ***
***                                                                          ***
***  Copyright (C) 2017, 2018, 2019, 2020, 2021, 2022, 2023, 2024            ***
***  John Schneiderman <Licencing _AT_ Schneiderman _DOT_ me>                ***
***                                                                          ***
***  This program is free software: you can redistribute it and/or modify it ***
***  under the terms of the GNU Affero General Public License as published   ***
***  by the Free Software Foundation, either version 3 of the License, or    ***
***  (at your option) any later version.                                     ***
***                                                                          ***
***  This program is distributed in the hope that it will be useful, but     ***
***  WITHOUT ANY WARRANTY; without even the implied warranty of              ***
***  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    ***
***  See the GNU Affero General Public License for more details.             ***
***                                                                          ***
***  You should have received a copy of the GNU Affero General Public License***
***  along with this program. If not, see <http://www.gnu.org/licenses/>.    ***
*******************************************************************************/
#ifndef DRN_CONFIG_H_
#define DRN_CONFIG_H_

/**
 * @brief Major version number of the project. Represents the first number in semantic
 * versioning (X.y.z).
 */
#define PROJECT_VERSION_MAJOR 1
/**
 * @brief Minor version number of the project. Represents the second number in semantic
 * versioning (x.Y.z).
 */
#define PROJECT_VERSION_MINOR 0
/**
 * @brief Patch version number of the project. Represents the third number in semantic
 * versioning (x.y.Z).
 */
#define PROJECT_VERSION_PATCH 0
/**
 * @brief Complete version string of the project. Contains the full version number in format
 * "MAJOR.MINOR.PATCH".
 *
 * @note Only defined if a pre-release version is specified
 */
#define PROJECT_VERSION "1.0.0"
/**
 * @brief Pre-release identifier for the project. Optional label indicating pre-release status
 * (e.g., "alpha", "beta", "rc").
 *
 * @note Only defined if a pre-release version is specified
 */
#define PROJECT_PRE_RELEASE "alpha"
/**
 * @brief Packaging revision number of the pre-release identifier. Numeric identifier for the
 * specific packaging revision.
 *
 * @note Only defined if revision tracking is enabled
 */
#define PROJECT_REVISION 17
/**
 * @brief Semantic version string. Version string following semantic versioning format
 * (MAJOR.MINOR.PATCH[-PRERELEASE]).
 *
 * @note Only defined if semantic versioning is enabled
 */
#define PROJECT_SEMANTIC_VERSION "1.0.0-alpha.17"
/**
 * @brief Build metadata information. Additional build-specific metadata (e.g., git commit hash).
 *
 * @note Only defined if build metadata is available
 */
#define PROJECT_METADATA "de67c545"
/**
 * @brief Complete semantic version with metadata. Full version string including pre-release and
 * metadata information.
 *
 * @note Only defined if semantic versioning with metadata is enabled
 */
#define PROJECT_SEMANTIC_META_VERSION "1.0.0-alpha.17+de67c545"
/**
 * @brief Project homepage URL. Web address where the project can be found.
 *
 * @note Configured based on PROJECT_HOMEPAGE_URL
 */
#define PROJECT_HOMEPAGE_URL "http://www.budgetnav.com"
/**
 * @brief Project description. Brief description of the project's purpose.
 *
 * @note Configured based on PROJECT_DESCRIPTION
 */
#define PROJECT_DESCRIPTION "Simple and powerful budgeting application"
/**
 * @brief The current known years of copyright claim.
 */
#define DuxReiNummariae_COPYRIGHT_YEARS "2017 - 2024"
/// The full form of the application name.
#define DuxReiNummariae_APPLICATION_LONG_NAME "Dux Rei Nummariae"
/// The full translated form of the application name.
#define DuxReiNummariae_APPLICATION_TRANSLATED_NAME "Budget Navigator"
/// The abbreviated form of the application name.
#define DuxReiNummariae_APPLICATION_SHORT_NAME "DRN"
/// The name of the organisation that produced the application.
#define DuxReiNummariae_ORGANIZATION_NAME "AureliusSoft"
/// The API key to use with OpenExchange when updating exchange rates.
#define DuxReiNummariae_OPEN_EXCHANGE_RATES_API_KEY "aaf744e881c94fdb82db913e6a2cb784"
/// The Heptapod project access token to use with all requests.
#define DuxReiNummariae_PROJECT_ACCESS_TOKEN "yxCXapEiptceyw7y_pUL"
/// The Heptapod Project ID to use for all requests to it.
#define DuxReiNummariae_PROJECT_ID "1069"

#endif
