/*******************************************************************************
***  This file is part of Dux Rei Nummariae.                                 ***
***                                                                          ***
***  Copyright (C) 2017, 2018, 2019, 2020, 2021, 2022, 2023, 2024            ***
***  John Schneiderman <Licencing _AT_ Schneiderman _DOT_ me>                ***
***                                                                          ***
***  This program is free software: you can redistribute it and/or modify it ***
***  under the terms of the GNU Affero General Public License as published   ***
***  by the Free Software Foundation, either version 3 of the License, or    ***
***  (at your option) any later version.                                     ***
***                                                                          ***
***  This program is distributed in the hope that it will be useful, but     ***
***  WITHOUT ANY WARRANTY; without even the implied warranty of              ***
***  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    ***
***  See the GNU Affero General Public License for more details.             ***
***                                                                          ***
***  You should have received a copy of the GNU Affero General Public License***
***  along with this program. If not, see <http://www.gnu.org/licenses/>.    ***
*******************************************************************************/
#ifndef DRN_DESKTOP_UI_DESKTOP_UI_ERRORS_H_
#define DRN_DESKTOP_UI_DESKTOP_UI_ERRORS_H_

#include <desktop-ui_export.h>
#include <foundation/Error.h>


class QString;

namespace drn::desktop_ui
{

/**
 * @brief Represents an error with the data in a widget.
 */
struct DRN_DESKTOP_UI_EXPORT DataEntryError final : foundation::Error
{
	/**
	 * Constructor for creating a specialised message for a data entry issue. The message is in the
	 * form of errorValue in dataEntryType then detailedMessage.
	 *
	 * @param dataEntryType The type of the widget that has the issue.
	 * @param errorValue The invalid value for that widget type.
	 * @param detailedMessage The detailed reason why the value is invalid.
	 * @param root When supplied, the exception that originally caused an issue.
	 */
	DataEntryError(
		const ::QString& dataEntryType,
		const ::QString& errorValue,
		const ::QString& detailedMessage,
		const std::exception& root = {}
	);
	DataEntryError(
		const char*,
		const ::QString&,
		const ::QString&,
		const std::exception& = {}
	) = delete;
	DataEntryError(
		const ::QString&,
		const char*,
		const ::QString&,
		const std::exception& = {}
	) = delete;
	DataEntryError(
		const ::QString&,
		const ::QString&,
		const char*,
		const std::exception& = {}
	) = delete;
	DataEntryError(
		const char*,
		const char*,
		const ::QString&,
		const std::exception& = {}
	) = delete;
	DataEntryError(
		const ::QString&,
		const char*,
		const char*,
		const std::exception& = {}
	) = delete;
	DataEntryError(
		const char*,
		const ::QString&,
		const char*,
		const std::exception& = {}
	) = delete;
	DataEntryError(
		const char*,
		const char*,
		const char*,
		const std::exception& = {}
	) = delete;
};

}

#endif
