/*******************************************************************************
***  This file is part of Dux Rei Nummariae.                                 ***
***                                                                          ***
***  Copyright (C) 2017, 2018, 2019, 2020, 2021, 2022, 2023, 2024            ***
***  John Schneiderman <Licencing _AT_ Schneiderman _DOT_ me>                ***
***                                                                          ***
***  This program is free software: you can redistribute it and/or modify it ***
***  under the terms of the GNU Affero General Public License as published   ***
***  by the Free Software Foundation, either version 3 of the License, or    ***
***  (at your option) any later version.                                     ***
***                                                                          ***
***  This program is distributed in the hope that it will be useful, but     ***
***  WITHOUT ANY WARRANTY; without even the implied warranty of              ***
***  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    ***
***  See the GNU Affero General Public License for more details.             ***
***                                                                          ***
***  You should have received a copy of the GNU Affero General Public License***
***  along with this program. If not, see <http://www.gnu.org/licenses/>.    ***
*******************************************************************************/
#ifndef DRN_FILE_STORAGE_FILESTORAGEERRORS_H_
#define DRN_FILE_STORAGE_FILESTORAGEERRORS_H_

#include <QString>

#include <foundation/Error.h>
#include <file-storage_export.h>
#include <storage/StorageErrors.h>


namespace drn
{
namespace file_storage
{

struct DRN_FILE_STORAGE_EXPORT BudgetFileError : storage::StorageError
{
	BudgetFileError(
		const QString& errorString,
		const qint64& lineNumber,
		const qint64& columnNumber,
		const QString& message,
		const std::exception& root = {}
	);
	BudgetFileError(
		const QString&,
		const qint64&,
		const qint64&,
		const char*,
		const std::exception& = {}
	) = delete;
};
struct DRN_FILE_STORAGE_EXPORT AttributeError final : BudgetFileError
{
	AttributeError(
		const QString& tagName,
		const QLatin1String& attributeName,
		const QString& errorString,
		const qint64& lineNumber,
		const qint64& columnNumber,
		const QString& message,
		const std::exception& root = {}
	);
	AttributeError(
		const QString&,
		const QLatin1String&,
		const QString&,
		const qint64&,
		const qint64&,
		const char*,
		const std::exception& = {}
	) = delete;
};
struct DRN_FILE_STORAGE_EXPORT BinaryFileError final : storage::StorageError
{
	BinaryFileError(
		const QString& fileName,
		const QString& message,
		const std::exception root = {}
	);
	BinaryFileError(
		const QString&,
		const char*,
		const std::exception = {}
	) = delete;
};

}}

#endif
