/*******************************************************************************
***  This file is part of Dux Rei Nummariae.                                 ***
***                                                                          ***
***  Copyright (C) 2017, 2018, 2019, 2020, 2021, 2022, 2023, 2024            ***
***  John Schneiderman <Licencing _AT_ Schneiderman _DOT_ me>                ***
***                                                                          ***
***  This program is free software: you can redistribute it and/or modify it ***
***  under the terms of the GNU Affero General Public License as published   ***
***  by the Free Software Foundation, either version 3 of the License, or    ***
***  (at your option) any later version.                                     ***
***                                                                          ***
***  This program is distributed in the hope that it will be useful, but     ***
***  WITHOUT ANY WARRANTY; without even the implied warranty of              ***
***  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    ***
***  See the GNU Affero General Public License for more details.             ***
***                                                                          ***
***  You should have received a copy of the GNU Affero General Public License***
***  along with this program. If not, see <http://www.gnu.org/licenses/>.    ***
*******************************************************************************/
#ifndef DRN_FOUNDATION_ALGORITHM_HPP_
#define DRN_FOUNDATION_ALGORITHM_HPP_

#include <type_traits>


namespace drn::foundation
{

/**
 * @brief Determines whether a specific element exists within a given collection.
 *
 * This method checks whether the provided collection (referred to as the "haystack") contains
 * the specified element (referred to as the "needle"). It is designed to standardise and simplify
 * the process of locating elements within collections, providing a utility function that can be
 * reused across various scenarios.
 *
 * @tparam HaystackType The type of the collection that contains the data.
 * @tparam NeedleType   The type of the element to be searched for.
 *
 * @param haystack The collection in which to search for the element.
 * @param needle   The element to search for within the collection.
 *
 * @return True if the `needle` is found within the `haystack`; false otherwise.
 */
template <typename HaystackType, typename NeedleType>
requires std::is_same_v<typename HaystackType::value_type, NeedleType>
[[nodiscard]]
bool contains(const HaystackType& haystack, const NeedleType& needle);

}

#include "Algorithm.tpp"

#endif
