/*******************************************************************************
***  This file is part of Dux Rei Nummariae.                                 ***
***                                                                          ***
***  Copyright (C) 2017, 2018, 2019, 2020, 2021, 2022, 2023, 2024            ***
***  John Schneiderman <Licencing _AT_ Schneiderman _DOT_ me>                ***
***                                                                          ***
***  This program is free software: you can redistribute it and/or modify it ***
***  under the terms of the GNU Affero General Public License as published   ***
***  by the Free Software Foundation, either version 3 of the License, or    ***
***  (at your option) any later version.                                     ***
***                                                                          ***
***  This program is distributed in the hope that it will be useful, but     ***
***  WITHOUT ANY WARRANTY; without even the implied warranty of              ***
***  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    ***
***  See the GNU Affero General Public License for more details.             ***
***                                                                          ***
***  You should have received a copy of the GNU Affero General Public License***
***  along with this program. If not, see <http://www.gnu.org/licenses/>.    ***
*******************************************************************************/
#ifndef DRN_FOUNDATION_ENUM_FLAGS_HPP_
#error Template definiton files should never be included directly.
#endif


template<typename FlagType>
std::enable_if_t<
	drn::foundation::detail::IsRegisteredEnumerationFlag<FlagType>::value, FlagType
> drn::foundation::operator|(const FlagType lhs, const FlagType rhs) noexcept
{
	return static_cast<FlagType>(static_cast<std::underlying_type_t<FlagType>>(lhs)
			| static_cast<std::underlying_type_t<FlagType>>(rhs));
}

template<typename FlagType>
std::enable_if_t<
	drn::foundation::detail::IsRegisteredEnumerationFlag<FlagType>::value, FlagType
> drn::foundation::operator&(const FlagType lhs, const FlagType rhs) noexcept
{
	return static_cast<FlagType>(static_cast<std::underlying_type_t<FlagType>>(lhs)
			& static_cast<std::underlying_type_t<FlagType>>(rhs));
}

template<typename FlagType>
std::enable_if_t<
	drn::foundation::detail::IsRegisteredEnumerationFlag<FlagType>::value, bool
> drn::foundation::operator==(const FlagType lhs, const FlagType rhs) noexcept
{
	return static_cast<std::underlying_type_t<FlagType>>(lhs)
			== static_cast<std::underlying_type_t<FlagType>>(rhs);
}

template<typename FlagType>
std::enable_if_t<
	drn::foundation::detail::IsRegisteredEnumerationFlag<FlagType>::value, bool
> drn::foundation::isSet(const FlagType flag, const FlagType mask) noexcept
{
	const auto maskedFlag{flag & mask};
	return maskedFlag == mask;
}
