/*******************************************************************************
***  This file is part of Dux Rei Nummariae.                                 ***
***                                                                          ***
***  Copyright (C) 2017, 2018, 2019, 2020, 2021, 2022, 2023, 2024            ***
***  John Schneiderman <Licencing _AT_ Schneiderman _DOT_ me>                ***
***                                                                          ***
***  This program is free software: you can redistribute it and/or modify it ***
***  under the terms of the GNU Affero General Public License as published   ***
***  by the Free Software Foundation, either version 3 of the License, or    ***
***  (at your option) any later version.                                     ***
***                                                                          ***
***  This program is distributed in the hope that it will be useful, but     ***
***  WITHOUT ANY WARRANTY; without even the implied warranty of              ***
***  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    ***
***  See the GNU Affero General Public License for more details.             ***
***                                                                          ***
***  You should have received a copy of the GNU Affero General Public License***
***  along with this program. If not, see <http://www.gnu.org/licenses/>.    ***
*******************************************************************************/
#ifndef DRN_FOUNDATION_OBSERVER_PTR_HPP_
#error Template definiton files should never be included directly.
#endif

#include <cassert>

template<typename ObservedType>
drn::foundation::ObserverPtr<ObservedType>::ObserverPtr(ObservedType* const observe) :
	observed_{observe}
{}

template<typename ObservedType>
drn::foundation::ObserverPtr<ObservedType>::ObserverPtr(
	const std::unique_ptr<ObservedType>& observe
) :
	ObserverPtr{observe.get()}
{}

template<typename ObservedType>
drn::foundation::ObserverPtr<ObservedType>::ObserverPtr(const UniqueQtPtr<ObservedType>& observe) :
	ObserverPtr{observe.get()}
{}

template<typename ObservedType>
drn::foundation::ObserverPtr<ObservedType>& drn::foundation::ObserverPtr<ObservedType>::operator=(
	ObservedType* const observe
)
{
	this->observed_ = observe;
	return *this;
}

template<typename ObservedType>
drn::foundation::ObserverPtr<ObservedType>& drn::foundation::ObserverPtr<ObservedType>::operator=(
	const std::nullptr_t
)
{
	this->observed_ = nullptr;
	return *this;
}

template<typename ObservedType>
bool drn::foundation::ObserverPtr<ObservedType>::operator==(const std::nullptr_t) const
{
	return this->observed_ == nullptr;
}

template<typename ObservedType>
bool drn::foundation::ObserverPtr<ObservedType>::operator==(const ObserverPtr& other) const
{
	return this->observed_ == other.observed_;
}

template<typename ObservedType>
bool drn::foundation::ObserverPtr<ObservedType>::operator==(const ObservedType* observed) const
{
	return this->observed_ == observed;
}

template<typename ObservedType>
bool drn::foundation::ObserverPtr<ObservedType>::operator!=(const std::nullptr_t) const
{
	return ! (*this == nullptr);
}

template<typename ObservedType>
bool drn::foundation::ObserverPtr<ObservedType>::operator!=(const ObserverPtr& other) const
{
	return ! (*this == other);
}

template<typename ObservedType>
bool drn::foundation::ObserverPtr<ObservedType>::operator!=(const ObservedType* observed) const
{
	return ! (*this == observed);
}

template<typename ObservedType>
bool drn::foundation::ObserverPtr<ObservedType>::operator<(const ObservedType* observed) const
{
	return std::less<const ObservedType*>{}(this->observed_, observed);
}

template<typename ObservedType>
bool drn::foundation::ObserverPtr<ObservedType>::operator<(const ObserverPtr& other) const
{
	return *this < other.observed_;
}

template<typename ObservedType>
ObservedType* drn::foundation::ObserverPtr<ObservedType>::get() const noexcept
{
	return this->observed_;
}

template<typename ObservedType>
ObservedType& drn::foundation::ObserverPtr<ObservedType>::operator*()
{
	assert(this->observed_ != nullptr && "Should not access the pointed object when it's null.");
	return *this->observed_;
}

template<typename ObservedType>
ObservedType& drn::foundation::ObserverPtr<ObservedType>::operator*() const
{
	assert(this->observed_ != nullptr && "Should not access the pointed object when it's null.");
	return *this->observed_;
}

template<typename ObservedType>
ObservedType* drn::foundation::ObserverPtr<ObservedType>::operator->()
{
	assert(this->observed_ != nullptr && "Should not access the pointed object when it's null.");
	return this->observed_;
}

template<typename ObservedType>
ObservedType* drn::foundation::ObserverPtr<ObservedType>::operator->() const
{
	assert(this->observed_ != nullptr && "Should not access the pointed object when it's null.");
	return this->observed_;
}

template<typename ObservedType>
drn::foundation::ObserverPtr<ObservedType>::operator bool() const noexcept
{
	return this->observed_ != nullptr;
}

template<typename ObservedType>
drn::foundation::ObserverPtr<ObservedType>::operator ObservedType*() const noexcept
{
	return this->observed_;
}

template<typename ObservedType>
bool drn::foundation::operator==(std::nullptr_t, const ObserverPtr<ObservedType>& rhs)
{
	return rhs == nullptr;
}

template<typename ObservedType, typename ObservedPtrType>
bool drn::foundation::operator==(const ObservedType* lhs, const ObserverPtr<ObservedPtrType>& rhs)
{
	return lhs == rhs.get();
}

template<typename ObservedType>
bool drn::foundation::operator!=(std::nullptr_t, const ObserverPtr<ObservedType>& rhs)
{
	return ! (nullptr == rhs);
}

template<typename ObservedType, typename ObservedPtrType>
bool drn::foundation::operator!=(const ObservedType* lhs, const ObserverPtr<ObservedPtrType>& rhs)
{
	return ! (lhs == rhs);
}

template<typename ObservedType>
std::ostream& drn::foundation::operator<<(
	std::ostream& o,
	const ObserverPtr<ObservedType>& observer
)
{
	if (observer == nullptr)
		return o << "<nullptr>";
	return o << *observer;
}

template<typename IsType, typename ObservedType>
bool drn::foundation::is(const drn::foundation::ObserverPtr<ObservedType>& observer) noexcept
{
	if (observer == nullptr)
		return false;
	return dynamic_cast<const IsType*>(observer.get()) != nullptr;
}

template<typename AsType, typename ObservedType>
AsType& drn::foundation::as(drn::foundation::ObserverPtr<ObservedType> observer)
{
	if (observer == nullptr)
		throw std::bad_cast{};
	return dynamic_cast<AsType&>(*observer);
}
