/*******************************************************************************
***  This file is part of Dux Rei Nummariae.                                 ***
***                                                                          ***
***  Copyright (C) 2017, 2018, 2019, 2020, 2021, 2022, 2023, 2024            ***
***  John Schneiderman <Licencing _AT_ Schneiderman _DOT_ me>                ***
***                                                                          ***
***  This program is free software: you can redistribute it and/or modify it ***
***  under the terms of the GNU Affero General Public License as published   ***
***  by the Free Software Foundation, either version 3 of the License, or    ***
***  (at your option) any later version.                                     ***
***                                                                          ***
***  This program is distributed in the hope that it will be useful, but     ***
***  WITHOUT ANY WARRANTY; without even the implied warranty of              ***
***  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    ***
***  See the GNU Affero General Public License for more details.             ***
***                                                                          ***
***  You should have received a copy of the GNU Affero General Public License***
***  along with this program. If not, see <http://www.gnu.org/licenses/>.    ***
*******************************************************************************/
#ifndef DRN_FOUNDATION_OPTIONAL_HPP_
#error Template definiton files should never be included directly.
#endif

#include <QObject>
#include <QString>

#include <ostream>


template<typename ValueType>
std::ostream& std::operator<<(std::ostream& out, const std::optional<ValueType>& opt) // NOLINT(*-dcl58-cpp)
{
#	pragma GCC diagnostic push
	// Justification: Stream insertion promotions would normally work as expected.
#	pragma GCC diagnostic ignored "-Wsign-promo"

	if (opt.has_value())
		return out << *opt;
	return out << "<optional-value-not-set>";

#	pragma GCC diagnostic pop
}

template<typename ValueType>
::QString drn::foundation::presentationText(const std::optional<ValueType>& opt)
{
	if (opt.has_value())
		return presentationText(*opt);
	return ::QObject::tr("Value Not Set");
}

template<typename ValueType>
ValueType drn::foundation::valueOrDefault(const std::optional<ValueType>& opt) noexcept
{
	return opt.value_or(ValueType{});
}

template<typename ExceptionType, typename ValueType, typename ... ExceptionArgs>
ValueType drn::foundation::valueOrThrow(
	const std::optional<ValueType>& value,
	ExceptionArgs... args
)
{
	if (value.has_value())
		return *value;
	throw ExceptionType{std::forward<ExceptionArgs>(args)...};
}
