/*******************************************************************************
***  This file is part of Dux Rei Nummariae.                                 ***
***                                                                          ***
***  Copyright (C) 2017, 2018, 2019, 2020, 2021, 2022, 2023, 2024            ***
***  John Schneiderman <Licencing _AT_ Schneiderman _DOT_ me>                ***
***                                                                          ***
***  This program is free software: you can redistribute it and/or modify it ***
***  under the terms of the GNU Affero General Public License as published   ***
***  by the Free Software Foundation, either version 3 of the License, or    ***
***  (at your option) any later version.                                     ***
***                                                                          ***
***  This program is distributed in the hope that it will be useful, but     ***
***  WITHOUT ANY WARRANTY; without even the implied warranty of              ***
***  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    ***
***  See the GNU Affero General Public License for more details.             ***
***                                                                          ***
***  You should have received a copy of the GNU Affero General Public License***
***  along with this program. If not, see <http://www.gnu.org/licenses/>.    ***
*******************************************************************************/
#ifndef DRN_FOUNDATION_SCOPEEXECUTOR_H
#define DRN_FOUNDATION_SCOPEEXECUTOR_H

#include <functional>

#include <foundation_export.h>


namespace drn::foundation
{

/**
 * @brief Provides a RAII way to execute a bit of code upon the destruction of the object.
 */
class DRN_FOUNDATION_EXPORT ScopeExecutor
{
	std::function<void()> execute_;

public:
	/**
	 * @brief Full initialisation constructor.
	 *
	 * @param execute The function that should be executed upon object destruction. The executable
	 * function must not throw.
	 */
	ScopeExecutor(std::function<void()> execute);
	/**
	 * @brief Executes the supplied function.
	 */
	~ScopeExecutor();
};

}

#endif
