/*******************************************************************************
***  This file is part of Dux Rei Nummariae.                                 ***
***                                                                          ***
***  Copyright (C) 2017, 2018, 2019, 2020, 2021, 2022, 2023, 2024            ***
***  John Schneiderman <Licencing _AT_ Schneiderman _DOT_ me>                ***
***                                                                          ***
***  This program is free software: you can redistribute it and/or modify it ***
***  under the terms of the GNU Affero General Public License as published   ***
***  by the Free Software Foundation, either version 3 of the License, or    ***
***  (at your option) any later version.                                     ***
***                                                                          ***
***  This program is distributed in the hope that it will be useful, but     ***
***  WITHOUT ANY WARRANTY; without even the implied warranty of              ***
***  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    ***
***  See the GNU Affero General Public License for more details.             ***
***                                                                          ***
***  You should have received a copy of the GNU Affero General Public License***
***  along with this program. If not, see <http://www.gnu.org/licenses/>.    ***
*******************************************************************************/
#ifndef DRN_FOUNDATION_STRING_MANIP_HPP
#define DRN_FOUNDATION_STRING_MANIP_HPP

#include <optional>

#include <foundation_export.h>


class QString;

namespace drn::foundation
{

/**
 * @brief Obfuscates a given string. Useful to obfuscate sensitive information in strings while
 * still showing enough characters to be potentially recognizable. This is particularly
 * useful in logging, debugging, or displaying sensitive data like secrets or passwords without
 * revealing the full value.
 *
 * @param input The string to be obfuscated.
 *
 * @return An obfuscated string showing only the first and last quarters, and replacing the middle
 * part with "..." if the string length is sufficiently long. If the length of the input string is
 * less than the minimum required number of characters, the function simply returns the obfuscation
 * character sequence "...".
 */
DRN_FOUNDATION_EXPORT ::QString obfuscate(const ::QString& input);
/**
 * @brief Obfuscates a given string. Useful to obfuscate sensitive information in strings while
 * still showing enough characters to be potentially recognizable. This is particularly
 * useful in logging, debugging, or displaying sensitive data like secrets or passwords without
 * revealing the full value.
 *
 * @param input The string to be obfuscated.
 *
 * @return When the supplied input has a value, an obfuscated string showing only the first and last
 * quarters, and replacing the middle part with "..." if the string length is sufficiently long.
 * If the length of the input string is less than the minimum required number of characters, the
 * function simply returns the obfuscation character sequence "...". If the input does not have a
 * value, a null optional is given.
 */
DRN_FOUNDATION_EXPORT std::optional<::QString> obfuscate(const std::optional<::QString>& input);

}

#endif
