/*******************************************************************************
***  This file is part of Dux Rei Nummariae.                                 ***
***                                                                          ***
***  Copyright (C) 2017, 2018, 2019, 2020, 2021, 2022, 2023, 2024            ***
***  John Schneiderman <Licencing _AT_ Schneiderman _DOT_ me>                ***
***                                                                          ***
***  This program is free software: you can redistribute it and/or modify it ***
***  under the terms of the GNU Affero General Public License as published   ***
***  by the Free Software Foundation, either version 3 of the License, or    ***
***  (at your option) any later version.                                     ***
***                                                                          ***
***  This program is distributed in the hope that it will be useful, but     ***
***  WITHOUT ANY WARRANTY; without even the implied warranty of              ***
***  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    ***
***  See the GNU Affero General Public License for more details.             ***
***                                                                          ***
***  You should have received a copy of the GNU Affero General Public License***
***  along with this program. If not, see <http://www.gnu.org/licenses/>.    ***
*******************************************************************************/
#ifndef DRN_NAVIGATION_BUDGET_BANK_ACCOUNT_H_
#define DRN_NAVIGATION_BUDGET_BANK_ACCOUNT_H_

#include <compare>
#include <set>

#include <budgeting/BudgetItemIdentifier.h>
#include <banking/BankAccount.h>

#include <navigation_export.h>


namespace drn::budgeting
{

class BudgetSource;

}
namespace drn::navigation
{

/**
 * @brief Represents the bank account for a budget item.
 */
struct DRN_NAVIGATION_EXPORT BudgetBankAccount
{
	[[nodiscard]]
	std::strong_ordering operator<=>(const BudgetBankAccount& other) const noexcept = default;

	/**
	 * @brief Uniquely identifies the budget item within the budgeting system.
	 */
	budgeting::BudgetItemIdentifier id_;
	/**
	 * @brief Represents the bank account used for tracking the finances of the budget item.
	 */
	banking::BankAccount bankAccount_;
};

/**
 * @brief Searches for a bank account associated with a given budget source in a provided
 * collection.
 *
 * @param toFind The budget item source for which a linked bank account is being sought. This serves
 * as the identifier for the search.
 * @param accounts A collection of budget bank accounts to be searched for the matching budget
 * source. The collection should represent all currently applicable budget sources.
 *
 * @return When found, gives the bank account associated with the given budget source, else gives an
 * empty value.
 */
DRN_NAVIGATION_EXPORT std::optional<banking::BankAccount> lookUpBankAccount(
	const budgeting::BudgetSource& toFind,
	const std::set<BudgetBankAccount>& accounts
) noexcept;

}

#endif
