/*******************************************************************************
***  This file is part of Dux Rei Nummariae.                                 ***
***                                                                          ***
***  Copyright (C) 2017, 2018, 2019, 2020, 2021, 2022, 2023, 2024            ***
***  John Schneiderman <Licencing _AT_ Schneiderman _DOT_ me>                ***
***                                                                          ***
***  This program is free software: you can redistribute it and/or modify it ***
***  under the terms of the GNU Affero General Public License as published   ***
***  by the Free Software Foundation, either version 3 of the License, or    ***
***  (at your option) any later version.                                     ***
***                                                                          ***
***  This program is distributed in the hope that it will be useful, but     ***
***  WITHOUT ANY WARRANTY; without even the implied warranty of              ***
***  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    ***
***  See the GNU Affero General Public License for more details.             ***
***                                                                          ***
***  You should have received a copy of the GNU Affero General Public License***
***  along with this program. If not, see <http://www.gnu.org/licenses/>.    ***
*******************************************************************************/
#ifndef DRN_NAVIGATION_PRIMARY_WIZARD_TEMPLATES_H_
#define DRN_NAVIGATION_PRIMARY_WIZARD_TEMPLATES_H_

#include <navigation_export.h>


class QDebug;

namespace drn::navigation
{

/**
 * @brief Enumerates the various budget templates for any wizard.
 *
 * This enumeration provides predefined templates to guide users through the setup process of an
 * application. Each template corresponds to a specific user category.
 */
enum class DRN_NAVIGATION_EXPORT BudgetWizardTemplates
{
	/// No budget template should be generated.
	None,
	/// The budget template corresponds to a child.
	Child,
	/// The budget template corresponds to the common finances of a teenager.
	Teenager,
	/// The budget template corresponds to the common finances of an adult that is single.
	AdultSingle,
	/// The budget template corresponds to the common finances of an adult that is married with a
	/// single income.
	AdultMarriedSingleIncome,
	/// The budget template corresponds to the common finances of an adult that is married with a
	/// dual income.
	AdultMarriedDoubleIncome,
};

/**
 * @brief Full object Qt stream insertion operator.
 *
 * @param out The stream to place the data into.
 * @param bwt The data to place into the stream.
 *
 * @return The modified stream after insertion.
 */
::QDebug operator<<(::QDebug out, BudgetWizardTemplates bwt);

}

#endif
