/*******************************************************************************
***  This file is part of Dux Rei Nummariae.                                 ***
***                                                                          ***
***  Copyright (C) 2017, 2018, 2019, 2020, 2021, 2022, 2023, 2024            ***
***  John Schneiderman <Licencing _AT_ Schneiderman _DOT_ me>                ***
***                                                                          ***
***  This program is free software: you can redistribute it and/or modify it ***
***  under the terms of the GNU Affero General Public License as published   ***
***  by the Free Software Foundation, either version 3 of the License, or    ***
***  (at your option) any later version.                                     ***
***                                                                          ***
***  This program is distributed in the hope that it will be useful, but     ***
***  WITHOUT ANY WARRANTY; without even the implied warranty of              ***
***  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    ***
***  See the GNU Affero General Public License for more details.             ***
***                                                                          ***
***  You should have received a copy of the GNU Affero General Public License***
***  along with this program. If not, see <http://www.gnu.org/licenses/>.    ***
*******************************************************************************/
#ifndef DRN_NAVIGATION_CONSTANTS_HPP_
#define DRN_NAVIGATION_CONSTANTS_HPP_

/**
 * @file Constants.hpp This is a collection of numerical and C-style string constants. This must not
 * include any declaration files.
 */

namespace drn::navigation
{

/**
 * @brief Specifies the delay, in milliseconds, for how long a message is displayed in the GUI.
 *
 * This variable determines the duration to wait before moving on from the current GUI item. It is
 * intended to enhance the user experience by providing a consistent delay for messages, improving
 * visual flow or interaction timing. Modifying this value can affect how quickly information is
 * displayed to the user, and the perceived responsiveness of the system.
 */
inline constexpr int guiMessageDisplayDelayMs{2000};
/**
 * @brief Specifies the delay, in milliseconds, used for emitting asynchronous signals/slots.
 *
 * This constant determines the time duration to wait before emitting the signals/slots. It is
 * essential for ensuring that certain operations have appropriate delays to allow for other
 * processes to complete, maintaining synchronisation, and responsiveness within the application.
 * Adjusting this value may impact performance, timing, and user experience, depending on
 * operational requirements.
 */
inline constexpr int signalAsyncDelayMs{100};
/**
 * @brief Defines the time, in milliseconds, for how long a status message is displayed in the GUI.
 *
 * This constant determines the duration for which status messages are visible in a GUI element,
 * such as a status bar, ensuring proper visibility for users to read the displayed information.
 * Adjusting this timeout value can tailor the user experience to either show messages for a shorter
 * or longer duration, adapting to both user preferences and application-specific needs.
 */
inline constexpr int statusMessageTimeOutMs{5000};

}

#endif
