/*******************************************************************************
***  This file is part of Dux Rei Nummariae.                                 ***
***                                                                          ***
***  Copyright (C) 2017, 2018, 2019, 2020, 2021, 2022, 2023, 2024            ***
***  John Schneiderman <Licencing _AT_ Schneiderman _DOT_ me>                ***
***                                                                          ***
***  This program is free software: you can redistribute it and/or modify it ***
***  under the terms of the GNU Affero General Public License as published   ***
***  by the Free Software Foundation, either version 3 of the License, or    ***
***  (at your option) any later version.                                     ***
***                                                                          ***
***  This program is distributed in the hope that it will be useful, but     ***
***  WITHOUT ANY WARRANTY; without even the implied warranty of              ***
***  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    ***
***  See the GNU Affero General Public License for more details.             ***
***                                                                          ***
***  You should have received a copy of the GNU Affero General Public License***
***  along with this program. If not, see <http://www.gnu.org/licenses/>.    ***
*******************************************************************************/
#ifndef DRN_NETWORKING_NETWORK_ERRORS_H_
#define DRN_NETWORKING_NETWORK_ERRORS_H_

#include <foundation/Error.h>
#include <networking_export.h>


class QString;

namespace drn::networking
{

struct FailureReply;

/**
 * @brief Represents an error with a network reply.
 */
struct DRN_NETWORKING_EXPORT ReplyError final : foundation::Error
{
	/**
	 * @brief Full initialisation constructor.
	 *
	 * @param failure The information on the source and cause of the failure.
	 * @param details Any additional details for the error message.
	 * @param root Any root exception triggering the error.
	 */
	ReplyError(
		const FailureReply& failure,
		const ::QString& details,
		const std::exception& root = {}
	);
	ReplyError(
		const FailureReply&,
		const char* details,
		const std::exception& = {}
	) = delete;
};
/**
 * @brief Represents an error with a network's URI hostname.
 */
struct DRN_NETWORKING_EXPORT HostError final : foundation::Error
{
	/**
	 * @brief Constructs an object with details about the error in a hostname.
	 *
	 * @param hostname The hostname related to the error.
	 * @param message A descriptive message of the error.
	 * @param root The optional root exception that caused this error.
	 */
	HostError(
		const ::QString& hostname,
		const ::QString& message,
		const std::exception& root = {}
	);
	HostError(const char* string, const std::exception& root) = delete;
};

}

#endif
