/*******************************************************************************
***  This file is part of Dux Rei Nummariae.                                 ***
***                                                                          ***
***  Copyright (C) 2017, 2018, 2019, 2020, 2021, 2022, 2023, 2024            ***
***  John Schneiderman <Licencing _AT_ Schneiderman _DOT_ me>                ***
***                                                                          ***
***  This program is free software: you can redistribute it and/or modify it ***
***  under the terms of the GNU Affero General Public License as published   ***
***  by the Free Software Foundation, either version 3 of the License, or    ***
***  (at your option) any later version.                                     ***
***                                                                          ***
***  This program is distributed in the hope that it will be useful, but     ***
***  WITHOUT ANY WARRANTY; without even the implied warranty of              ***
***  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    ***
***  See the GNU Affero General Public License for more details.             ***
***                                                                          ***
***  You should have received a copy of the GNU Affero General Public License***
***  along with this program. If not, see <http://www.gnu.org/licenses/>.    ***
*******************************************************************************/
#ifndef DRN_STORAGE_EXCHANGERATESSTORAGE_HPP_
#define DRN_STORAGE_EXCHANGERATESSTORAGE_HPP_

#include <QString>


namespace drn
{
namespace conversion
{

class ConversionMap;

}
namespace storage
{

/**
 * @brief The interface for interacting with the cached exchange rates.
 */
struct ExchangeRatesStorage
{
	ExchangeRatesStorage() = default;
	ExchangeRatesStorage(const ExchangeRatesStorage&) = default;
	ExchangeRatesStorage(ExchangeRatesStorage&&) = default;
	virtual ~ExchangeRatesStorage() = default;
	ExchangeRatesStorage& operator=(const ExchangeRatesStorage&) = default;
	ExchangeRatesStorage& operator=(ExchangeRatesStorage&&) = default;
	/**
	 * @brief When implemented, determines if the exchange rates cache exists.
	 *
	 * @return True when the cache exists, false else-wise.
	 */
	virtual bool exists() const noexcept = 0;
	/**
	 * @brief When implemented, removes the cached exchange rates.
	 */
	virtual void remove() const = 0;
	/**
	 * @brief When implemented, loads the cached exchange rates.
	 *
	 * @exception StorageError When the exchange rates cache is not valid.
	 *
	 * @return The loaded exchange rates.
	 */
	virtual drn::conversion::ConversionMap load() const = 0;
	/**
	 * @brief When implemented, creates or overwrites the exchange rates cache.
	 *
	 * @exception StorageError When the exchange rates cache cannot be saved.
	 *
	 * @param[in] cm The exchange rates whose contents are to be cached.
	 */
	virtual void store(const drn::conversion::ConversionMap& cm) const = 0;
};

}}

#endif
