/*******************************************************************************
***  This file is part of Dux Rei Nummariae.                                 ***
***                                                                          ***
***  Copyright (C) 2017, 2018, 2019, 2020, 2021, 2022, 2023, 2024            ***
***  John Schneiderman <Licencing _AT_ Schneiderman _DOT_ me>                ***
***                                                                          ***
***  This program is free software: you can redistribute it and/or modify it ***
***  under the terms of the GNU Affero General Public License as published   ***
***  by the Free Software Foundation, either version 3 of the License, or    ***
***  (at your option) any later version.                                     ***
***                                                                          ***
***  This program is distributed in the hope that it will be useful, but     ***
***  WITHOUT ANY WARRANTY; without even the implied warranty of              ***
***  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    ***
***  See the GNU Affero General Public License for more details.             ***
***                                                                          ***
***  You should have received a copy of the GNU Affero General Public License***
***  along with this program. If not, see <http://www.gnu.org/licenses/>.    ***
*******************************************************************************/
#ifndef DRN_STORAGE_STORAGEERRORS_H_
#define DRN_STORAGE_STORAGEERRORS_H_

#include <exception>

#include <foundation/Error.h>
#include <storage_export.h>


namespace drn::storage
{

struct DRN_STORAGE_EXPORT StorageError : foundation::Error
{
	/**
	 * @brief Fully initialisation constructor.
	 *
	 * @param errorString The details about what caused the error.
	 * @param message The generalised explanation of the error.
	 * @param root Any root error that caused the error.
	 */
	StorageError(
		const QString& errorString,
		const QString& message,
		const std::exception& root = {}
	);
	StorageError(const QString&, const char*, const std::exception& = {}) = delete;
};

}

#endif
